@@ -6,6 +6,8 @@ import pkg_resources
 from sqlalchemy import engine_from_config
 from paste.deploy.loadwsgi import ConfigLoader
 
+from nous.migration.add_script import new_version
+
 MIGRATION_SCRIPT_REGEX = re.compile(r'(?P<version>\d+)(_upgrade)*(_(?P<name>.*))*(.(?P<class>py|sql))$')
 
 
@@ -165,9 +167,6 @@ class DBMigrator(object):
         self.run_downgrade_scripts([version])
         tx.commit()
 
-    def add_script(self):
-        pass
-
 
 def main():
     config_file = sys.argv[1] if len(sys.argv) > 1 else 'development.ini'
@@ -179,16 +178,23 @@ def main():
     migrator_config = dict(clo.parser.items('nous.migration'))
     section = migrator_config['app']
     package = migrator_config['package']
+    schema_diff = migrator_config.get('schema_diff_cmd')
+    vcs = migrator_config.get('vcs', 'git')
+
+    if action == 'add_script':
+        try:
+            name = sys.argv[3]
+            editor = 'vim'
+        except IndexError:
+            print 'Usage: migrate development_ini add_script version_name'
+        new_version(package, name, script_type='sql', vcs=vcs, schema_diff=schema_diff, editor=editor)
+        return
 
     engine = engine_from_config(dict(clo.parser.items(section)))
-
     migrator = DBMigrator(engine, package)
-
     if action == 'upgrade':
         migrator.upgrade(version)
     if action == 'setup':
         migrator.set_up_migration(run_scripts=True)
     if action == 'downgrade':
         migrator.downgrade(version)
-    if action == 'add_script':
-        migrator.add_script()
